      subroutine unboundsep(n,energy,wfn,l,rveff,h,v0,v0p,proj,         &
       nmx,hij,qij,mxb,many,a,b,y,u,d1,d2)
!  pgm to solve separable radial schroedinger equation
!    at energy 'energy' and at angular momentum l
!
!    with smooth potential rveff/r, given in uniform mesh of n points
!   r=i*h, i=1,...n-1 ;assuming p(r)=C*r**(l+1)*polynomial(r) for r==0;
!                               p((n+1)*h)=0
!
!  uses Noumerov algorithm
!
!  For l=0,1 corrections are needed to approximate wfn(r=0)
!     These depend upon:
!         e0 (current guess of energy eigenvalue)
!         l,nz==0
!         v(0) == v0 electronic potential at r=0
!         v'(0) == v0p derivative of electronic potential at r=0
!
! also returns node == number of nodes for calculated state
!
!  proj == projector functions
!  hij and qij == hamiltonianian and overlap matrix elements
      implicit real*8 (a-h,o-z)
      dimension rveff(n),wfn(n),proj(nmx,many),y(nmx,many),u(nmx)
      dimension a(mxb,mxb),b(mxb),hij(mxb,mxb),qij(mxb,mxb)
      dimension d1(nmx),d2(nmx)
!
      if (n.gt.nmx) then
       write(6,*) 'error in unboundsep -- n,nmx=',n,nmx
       stop
      endif
      noz=0
      call outwardh(n,energy,u,l,noz,rveff,h,v0,v0p,node,nmx,d1,d2)
!
      do ib=1,many
      call outwardi(n,energy,y(1,ib),l,rveff,proj(1,ib),h,nmx,d1,d2)
      enddo
!
      do ib=1,many
      sum=0.d0
       do ic=1,many
       sum=sum+(hij(ib,ic)-energy*qij(ib,ic))*                          &
                 overlap(n,h,proj(1,ic),u)
       enddo
      b(ib)=-sum
!     write(6,*) 'ib,sum',ib,sum
      enddo
!
      do ia=1,many
      do ib=1,many
      sum=0.d0
      if (ia.eq.ib) sum=1.d0
       do ic=1,many
       sum=sum+(hij(ia,ic)-energy*qij(ia,ic))*                          &
                 overlap(n,h,proj(1,ic),y(1,ib))
       enddo
      a(ia,ib)=sum
!     write(6,*) 'ia,ib,sum',ia,ib,sum
      enddo
      enddo
!
      call linsol(a,b,mxb,many,1)
!     write(6,*) 'b(ib)=',(b(ib),ib=1,many)
      wfn(1:n)=u(1:n)  ! call dcopy(n,u,1,wfn,1)
      do ib=1,many
      wfn(1:n)=wfn(1:n)+b(ib)*y(1:n,ib)  ! call daxpy(n,b(ib),y(1,ib),1,wfn,1)
      enddo
!
! normalize to unity within integration range
!
      scale=1.d0/sepnorm(n,h,wfn,nmx,many,proj,b,mxb,qij)
      if (scale.le.0.d0) then
       write(6,*) 'warning -- negative norm for l=',l
       scale=-scale
       if (scale.eq.0.d0) scale=1.d0
       endif
      scale=sign(sqrt(scale),wfn(n-2))
      wfn(1:n)=wfn(1:n)*scale   ! call dscal(n,scale,wfn,1)
      return
       end
